@@ -395,7 +395,7 @@ class AssetsAPI(APIClient):
 
         Args:
             id (Union[int, Sequence[int]): Id or list of ids
-            external_id (Union[str, Sequence[str]]): External ID or list of exgernal ids
+            external_id (Union[str, Sequence[str]]): External ID or list of external ids
             recursive (bool): Recursively delete whole asset subtrees under given ids. Defaults to False.
             ignore_unknown_ids (bool): Ignore IDs and external IDs that are not found rather than throw an exception.
 
